Unifont Utils
=============

This project provides a set of tools for working with the Unifont font.

Installation
------------

Install the package from PyPI using the following command:

.. code-block:: shell

    pip install unifont_utils

Feedback
--------

Please feel free to raise issues for any problems encountered or
feature suggestions.

Pull requests are welcome.
